@@ -101,8 +101,8 @@ class InquirerPrompter:
         return i.Issue(0, answers["title"], answers["body"], labels)
 
     @staticmethod
-    def close_objects(github_selected_repos: List[str], object_name: str) -> str:
-        """Prompt questions to close issues or pull requests."""
+    def query_by_title(github_selected_repos: List[str], object_name: str) -> str:
+        """Prompt questions to close/reopen issues or pull requests."""
         questions = [
             inquirer.Text(
                 "object_title_query",
@@ -134,7 +134,7 @@ class InquirerPrompter:
             inquirer.Text(
                 "base",
                 message="Write base branch name (destination)",
-                default="master",
+                default="main",
                 validate=val.not_empty_validation,
             ),
             inquirer.Text(
@@ -234,7 +234,7 @@ class InquirerPrompter:
             inquirer.Text(
                 "base",
                 message="Write base branch name (destination)",
-                default="master",
+                default="main",
                 validate=val.not_empty_validation,
             ),
             inquirer.Text(
